@@ -1,10 +1,10 @@
 /*
  * wconfig.h- default configuration and definitions + compile time options
- * 
+ *
  *  WindowMaker window manager
- * 
- *  Copyright (c) 1997-2002 Alfredo K. Kojima
- * 
+ *
+ *  Copyright (c) 1997-2003 Alfredo K. Kojima
+ *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -30,9 +30,9 @@
 /*
  *--------------------------------------------------------------------
  * 			Feature Selection
- * 
- * 	Comment out the following #defines if you want to 
- * disable a feature. 
+ *
+ * 	Comment out the following #defines if you want to
+ * disable a feature.
  * 	Also check the features you can enable through configure.
  *--------------------------------------------------------------------
  */
@@ -62,17 +62,13 @@
 
 /* #define CPP_PATH /usr/bin/cpp */
 
-/*
- * support for OffiX DND drag and drop in the Dock
- */
-#define OFFIX_DND
+
+#define NETWM_HINTS
 
 /*
  * support for XDND drop in the Dock. Experimental
  */
-#ifdef GNOME_STUFF
-#define XDND
-#endif
+/*#define XDND*/
 
 /*
  * support for Motif window manager (mwm) window hints
@@ -94,18 +90,6 @@
 #define SHAPED_BALLOON
 
 
-/*
- * Define NO_EMERGENCY_AUTORESTART if you don't want another window manager
- * automatically started when WindowMaker crashes. The X session will die
- * in some cases if wmaker crashes and autorestart is disabled.
- */
-#undef NO_EMERGENCY_AUTORESTART
-
-/* 
- * The window manager that is autorestarted
- */
-#define FALLBACK_WINDOWMANAGER "blackbox"
-
 /*
  * Turn on a hack to make mouse and keyboard actions work even if
  * the NumLock or ScrollLock modifiers are turned on. They might
@@ -123,7 +107,7 @@
  * for applications that change their shape frequently (like xdaliclock
  * -shape), removing flickering. If wmaker and your display are on
  * different machines and the network connection is slow, it is not
- * recommended. 
+ * recommended.
  */
 #undef OPTIMIZE_SHAPE
 
@@ -138,7 +122,7 @@
 /*
  * disable/enable workspace indicator in the dock
  */
-#undef WS_INDICATOR 
+#undef WS_INDICATOR
 
 
 /*
@@ -217,7 +201,7 @@
 /*
  *--------------------------------------------------------------------
  * 			Default Configuration
- * 
+ *
  * 	Some of the following options can be configured in
  * the preference files, but if for some reason, they can't
  * be used, these defaults will be.
@@ -226,10 +210,10 @@
  *--------------------------------------------------------------------
  */
 
-/* list of paths to look for the config files, searched in order 
+/* list of paths to look for the config files, searched in order
  * of appearance */
 #define DEF_CONFIG_PATHS \
-"~/GNUstep/Library/WindowMaker:"PKGDATADIR
+    "~/GNUstep/Library/WindowMaker:"PKGDATADIR
 
 #define DEF_MENU_FILE	"menu"
 
@@ -247,24 +231,23 @@
 #endif
 
 /* the file of the system wide submenu to be forced into the main menu */
-/* remove the comments if you want it */
-/*
-#define GLOBAL_SUBMENU_FILE PKGDATADIR"/GlobalMenu"
-*/
+#define GLOBAL_PREAMBLE_MENU_FILE "GlobalMenu.pre"
+#define GLOBAL_EPILOGUE_MENU_FILE "GlobalMenu.post"
+
 
 /* pixmap path */
 #define DEF_PIXMAP_PATHS \
-"(\"~/pixmaps\",\"~/GNUstep/Library/WindowMaker/Pixmaps\",\""PIXMAPDIR"\")"
+    "(\"~/pixmaps\",\"~/GNUstep/Library/WindowMaker/Pixmaps\",\""PIXMAPDIR"\")"
 
 #ifdef USER_MENU
 #define GLOBAL_USER_MENU_PATH PKGDATADIR"/UserMenus"
 #define DEF_USER_MENU_PATHS \
-"~/GNUstep/Library/WindowMaker/UserMenus:"GLOBAL_USER_MENU_PATH
+    "~/GNUstep/Library/WindowMaker/UserMenus:"GLOBAL_USER_MENU_PATH
 #endif
 
 /* icon path */
 #define DEF_ICON_PATHS \
-"(\"~/pixmaps\",\"~/GNUstep/Library/Icons\",\"/usr/include/X11/pixmaps/\",\""PIXMAPDIR"\")"
+    "(\"~/pixmaps\",\"~/GNUstep/Library/Icons\",\"/usr/include/X11/pixmaps/\",\""PIXMAPDIR"\")"
 
 
 /* window title to use for untitled windows */
@@ -274,28 +257,15 @@
 #define DEF_FRAME_COLOR   "white"
 
 
-#ifdef I18N
-#define DEF_TITLE_FONT "\"-*-*-medium-r-normal--14-*\""
-#define DEF_MENU_TITLE_FONT "\"-*-*-medium-r-normal--14-*\""
-#define DEF_MENU_ENTRY_FONT "\"-*-*-medium-r-normal--14-*\""
-#define DEF_ICON_TITLE_FONT "\"-*-*-medium-r-normal--10-*\""
-#define DEF_CLIP_TITLE_FONT "\"-*-*-medium-r-normal--10-*\""
-#define DEF_INFO_TEXT_FONT "\"-*-*-medium-r-normal--14-*\""
-#define DEF_ADDITONAL_FONT "-*-*-medium-r-normal--12-*"
+#define DEF_TITLE_FONT "\"Trebuchet MS,Luxi Sans:bold:pixelsize=12\""
+#define DEF_MENU_TITLE_FONT "\"Trebuchet MS,Luxi Sans:bold:pixelsize=12\""
+#define DEF_MENU_ENTRY_FONT "\"Trebuchet MS,Luxi Sans:pixelsize=12\""
+#define DEF_ICON_TITLE_FONT "\"Arial,Luxi Sans:pixelsize=9\""
+#define DEF_CLIP_TITLE_FONT "\"Verdana:bold:pixelsize=10\""
+#define DEF_INFO_TEXT_FONT "\"Trebuchet MS,Luxi Sans:pixelsize=12\""
 
-#define DEF_WORKSPACE_NAME_FONT "\"-*-*-medium-r-normal--24-*\""
-#else /* !I18N */
-#define DEF_TITLE_FONT "\"-*-helvetica-bold-r-normal-*-12-*-*-*-*-*-*-*\""
-#define DEF_MENU_TITLE_FONT "\"-*-helvetica-bold-r-normal-*-12-*-*-*-*-*-*-*\""
-#define DEF_MENU_ENTRY_FONT "\"-*-helvetica-medium-r-normal-*-12-*-*-*-*-*-*-*\""
-#define DEF_ICON_TITLE_FONT "\"-*-helvetica-medium-r-normal-*-8-*-*-*-*-*-*-*\""
-#define DEF_CLIP_TITLE_FONT "\"-*-helvetica-bold-r-normal-*-10-*-*-*-*-*-*-*\""
-#define DEF_INFO_TEXT_FONT "\"-*-helvetica-medium-r-normal-*-12-*-*-*-*-*-*-*\""
+#define DEF_WORKSPACE_NAME_FONT "\"Trebuchet MS,Luxi Sans:pixelsize=24\""
 
-#define DEF_WORKSPACE_NAME_FONT "\"-*-lucida-bold-r-*-*-24-*-*-*-*-*-*-*\""
-#endif /* !I18N */
-
-#define HELVETICA10_FONT "-*-helvetica-medium-r-normal-*-10-*-*-*-*-*-*-*"
 
 #define DEF_FRAME_THICKNESS 1	       /* linewidth of the move/resize frame */
 
@@ -304,7 +274,7 @@
 #define DEF_MENU_TEXT_EXTEND_SPACE	"0"
 #define TITLEBAR_EXTEND_SPACE 4
 
-#define DEF_XPM_CLOSENESS	40000 
+#define DEF_XPM_CLOSENESS	40000
 
 /* default position of application menus */
 #define DEF_APPMENU_X		10
@@ -316,7 +286,7 @@
 /* Window level where icons reside */
 #define NORMAL_ICON_LEVEL WMNormalLevel
 
-/* do not divide main menu and submenu in different tiers, 
+/* do not divide main menu and submenu in different tiers,
  * opposed to OpenStep */
 #define SINGLE_MENULEVEL
 
@@ -329,29 +299,29 @@
 /* Zoom animation */
 #define MINIATURIZE_ANIMATION_FRAMES_Z   5
 #define MINIATURIZE_ANIMATION_STEPS_Z    12
-#define MINIATURIZE_ANIMATION_DELAY_Z    500
+#define MINIATURIZE_ANIMATION_DELAY_Z    10000
 /* Twist animation */
 #define MINIATURIZE_ANIMATION_FRAMES_T   12
 #define MINIATURIZE_ANIMATION_STEPS_T    16
-#define MINIATURIZE_ANIMATION_DELAY_T    1000
+#define MINIATURIZE_ANIMATION_DELAY_T    20000
 #define MINIATURIZE_ANIMATION_TWIST_T    0.5
 /* Flip animation */
 #define MINIATURIZE_ANIMATION_FRAMES_F   12
 #define MINIATURIZE_ANIMATION_STEPS_F    16
-#define MINIATURIZE_ANIMATION_DELAY_F    1000
+#define MINIATURIZE_ANIMATION_DELAY_F    20000
 #define MINIATURIZE_ANIMATION_TWIST_F    0.5
-  
+
 
 #define HIDE_ANIMATION_STEPS (MINIATURIZE_ANIMATION_STEPS*2/3)
 
-/* delay before balloon is showed */
-#define BALLOON_DELAY	1000
+/* delay before balloon is shown (ms) */
+#define BALLOON_DELAY           1000
 
-/* delay for menu item selection hysteresis */
-#define MENU_SELECT_DELAY 200
+/* delay for menu item selection hysteresis (ms) */
+#define MENU_SELECT_DELAY       200
 
-/* delay for jumpback of scrolled menus */
-#define MENU_JUMP_BACK_DELAY 	400
+/* delay for jumpback of scrolled menus (ms) */
+#define MENU_JUMP_BACK_DELAY    400
 
 /* *** animation speed constants *** */
 
@@ -413,7 +383,7 @@
 /* workspace name on switch display */
 #define WORKSPACE_NAME_FADE_DELAY 30
 
-#ifdef VIRTUAL_DESKTOP 
+#ifdef VIRTUAL_DESKTOP
 /* workspace virtual edge speed */
 #define VIRTUALEDGE_SCROLL_VSTEP 30
 #define VIRTUALEDGE_SCROLL_HSTEP 30
@@ -477,18 +447,18 @@
 #define CURSOR_BLINK_RATE	300
 
 #define MOVE_THRESHOLD	5 /* how many pixels to move before dragging windows
-			   * and other objects */
+                           * and other objects */
 
 #define KEY_CONTROL_WINDOW_WEIGHT 1
 
 #define HRESIZE_THRESHOLD	3
 
-#define MAX_WORKSPACENAME_WIDTH	16
+#define MAX_WORKSPACENAME_WIDTH	32
 #define MAX_WINDOWLIST_WIDTH	160     /* max width of window title in
-					 * window list */
+                                         * window list */
 
 #define DEFAULTS_CHECK_INTERVAL 2000	/* how often wmaker will check for
-					 * changes in the config files */
+                                         * changes in the config files */
 
 /* if your keyboard don't have arrow keys */
 #undef ARROWLESS_KBD
@@ -539,12 +509,7 @@
 #define MAX_ICON_WIDTH	60	       /* size of the icon pixmap */
 #define MAX_ICON_HEIGHT 48
 
-/* KDE may have problems with more than 32 workspaces */
-#ifdef KWM_HINTS
-# define MAX_WORKSPACES 32
-#else
-# define MAX_WORKSPACES  100
-#endif
+#define MAX_WORKSPACES  100
 
 #define MAX_MENU_TEXT_LENGTH 512
 
